Class: Google::Cloud::Build::V2::InstallationState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/devtools/cloudbuild/v2/repositories.rb

Overview

Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections.

Defined Under Namespace

Modules: Stage

Instance Attribute Summary collapse

Instance Attribute Details

#action_uri::String (readonly)

Returns Output only. Link to follow for next action. Empty string if the installation is already complete.

Returns:

  • (::String)

    Output only. Link to follow for next action. Empty string if the installation is already complete.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/devtools/cloudbuild/v2/repositories.rb', line 110

class InstallationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stage of the installation process.
  module Stage
    # No stage specified.
    STAGE_UNSPECIFIED = 0

    # Only for GitHub Enterprise. An App creation has been requested.
    # The user needs to confirm the creation in their GitHub enterprise host.
    PENDING_CREATE_APP = 1

    # User needs to authorize the GitHub (or Enterprise) App via OAuth.
    PENDING_USER_OAUTH = 2

    # User needs to follow the link to install the GitHub (or Enterprise) App.
    PENDING_INSTALL_APP = 3

    # Installation process has been completed.
    COMPLETE = 10
  end
end

#message::String (readonly)

Returns Output only. Message of what the user should do next to continue the installation. Empty string if the installation is already complete.

Returns:

  • (::String)

    Output only. Message of what the user should do next to continue the installation. Empty string if the installation is already complete.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/devtools/cloudbuild/v2/repositories.rb', line 110

class InstallationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stage of the installation process.
  module Stage
    # No stage specified.
    STAGE_UNSPECIFIED = 0

    # Only for GitHub Enterprise. An App creation has been requested.
    # The user needs to confirm the creation in their GitHub enterprise host.
    PENDING_CREATE_APP = 1

    # User needs to authorize the GitHub (or Enterprise) App via OAuth.
    PENDING_USER_OAUTH = 2

    # User needs to follow the link to install the GitHub (or Enterprise) App.
    PENDING_INSTALL_APP = 3

    # Installation process has been completed.
    COMPLETE = 10
  end
end

#stage::Google::Cloud::Build::V2::InstallationState::Stage (readonly)

Returns Output only. Current step of the installation process.

Returns:



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/devtools/cloudbuild/v2/repositories.rb', line 110

class InstallationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stage of the installation process.
  module Stage
    # No stage specified.
    STAGE_UNSPECIFIED = 0

    # Only for GitHub Enterprise. An App creation has been requested.
    # The user needs to confirm the creation in their GitHub enterprise host.
    PENDING_CREATE_APP = 1

    # User needs to authorize the GitHub (or Enterprise) App via OAuth.
    PENDING_USER_OAUTH = 2

    # User needs to follow the link to install the GitHub (or Enterprise) App.
    PENDING_INSTALL_APP = 3

    # Installation process has been completed.
    COMPLETE = 10
  end
end